@@ -865,6 +865,12 @@ pref_window_page_initializer (PrefState *state,
 				 gnm_conf_get_core_gui_editing_portraitmode,
 				 _("Portrait Mode"));
 
+	bool_pref_create_widget (gnm_conf_get_core_gui_editing_launchpage_node (),
+				 page, row++,
+				 gnm_conf_set_core_gui_editing_launchpage,
+				 gnm_conf_get_core_gui_editing_launchpage,
+				 _("Use Launch Page"));
+
 	gtk_widget_show_all (page);
 	return page;
 }
