@@ -26,6 +26,7 @@
 #include <gnumeric.h>
 #include "dialogs.h"
 #include "help.h"
+#include <dead-kittens.h>
 
 #include <gui-util.h>
 #include <commands.h>
@@ -37,13 +38,12 @@
 #include <application.h>
 #include <workbook-cmd-format.h>
 
-#include <glade/glade.h>
 #include <gtk/gtk.h>
 
 #define ROW_HEIGHT_DIALOG_KEY "row-height-dialog"
 
 typedef struct {
-	GladeXML           *gui;
+	GtkBuilder         *gui;
 	WBCGtk *wbcg;
 	Sheet              *sheet;
 	SheetView	   *sv;
@@ -97,6 +97,7 @@ dialog_row_height_button_sensitivity (RowHeightState *state)
 /* Maemo specific: SpinButtons are without arrows */
 	changed_info = TRUE;
 #endif
+
 	gtk_widget_set_sensitive (state->ok_button, changed_info);
 	gtk_widget_set_sensitive (state->apply_button, changed_info);
 
@@ -268,43 +269,42 @@ dialog_row_height (WBCGtk *wbcg, gboolean use_default)
 	state->sv = wb_control_cur_sheet_view (WORKBOOK_CONTROL (wbcg));
 	state->sheet = sv_sheet (state->sv);
 	state->adjusting = FALSE;
-	state->gui = gnm_glade_xml_new (GO_CMD_CONTEXT (wbcg),
-		"row-height.glade", NULL, NULL);
+	state->gui = gnm_gtk_builder_new ("row-height.ui", NULL, GO_CMD_CONTEXT (wbcg));
 	g_return_if_fail (state->gui != NULL);
 
-	state->dialog = glade_xml_get_widget (state->gui, "dialog");
+	state->dialog = go_gtk_builder_get_widget (state->gui, "dialog");
 
-	state->description = GTK_WIDGET (glade_xml_get_widget (state->gui, "description"));
-	state->points = GTK_WIDGET (glade_xml_get_widget (state->gui, "pts-label"));
+	state->description = GTK_WIDGET (go_gtk_builder_get_widget (state->gui, "description"));
+	state->points = GTK_WIDGET (go_gtk_builder_get_widget (state->gui, "pts-label"));
 
-	state->spin  = GTK_ENTRY (glade_xml_get_widget (state->gui, "spin"));
-//	gtk_spin_button_get_adjustment (state->spin)->lower =
-//		GNM_ROW_MARGIN + GNM_ROW_MARGIN + 1;
+	state->spin  = GTK_ENTRY (go_gtk_builder_get_widget (state->gui, "spin"));
+	gtk_adjustment_set_lower (gtk_spin_button_get_adjustment (state->spin),
+				  GNM_ROW_MARGIN + GNM_ROW_MARGIN + 1);
 	g_signal_connect (G_OBJECT (state->spin),
 		"insert-at-cursor",
 		G_CALLBACK (cb_dialog_row_height_value_changed), state);
 
-	state->default_check  = GTK_WIDGET (glade_xml_get_widget (state->gui, "default_check"));
+	state->default_check  = GTK_WIDGET (go_gtk_builder_get_widget (state->gui, "default_check"));
 	g_signal_connect (G_OBJECT (state->default_check),
 		"clicked",
 		G_CALLBACK (cb_dialog_row_height_default_check_toggled), state);
 
-	state->ok_button = glade_xml_get_widget (state->gui, "ok_button");
+	state->ok_button = go_gtk_builder_get_widget (state->gui, "ok_button");
 	g_signal_connect (G_OBJECT (state->ok_button),
 		"clicked",
 		G_CALLBACK (cb_dialog_row_height_ok_clicked), state);
-	state->apply_button = glade_xml_get_widget (state->gui, "apply_button");
+	state->apply_button = go_gtk_builder_get_widget (state->gui, "apply_button");
 	g_signal_connect (G_OBJECT (state->apply_button),
 		"clicked",
 		G_CALLBACK (cb_dialog_row_height_apply_clicked), state);
 
-	state->cancel_button = glade_xml_get_widget (state->gui, "cancel_button");
+	state->cancel_button = go_gtk_builder_get_widget (state->gui, "cancel_button");
 	g_signal_connect (G_OBJECT (state->cancel_button),
 		"clicked",
 		G_CALLBACK (cb_dialog_row_height_cancel_clicked), state);
 
 	gnumeric_init_help_button (
-		glade_xml_get_widget (state->gui, "help_button"),
+		go_gtk_builder_get_widget (state->gui, "help_button"),
 		GNUMERIC_HELP_LINK_ROW_HEIGHT);
 	g_object_set_data_full (G_OBJECT (state->dialog),
 		"state", state, (GDestroyNotify) cb_dialog_row_height_destroy);
