@@ -1,3 +1,5 @@
+/* vim: set sw=8: -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
+
 /*
  * dialog-search-replace.c:
  *   Dialog for entering a search-and-replace query.
@@ -25,14 +27,15 @@
 #include <gnumeric.h>
 #include "dialogs.h"
 #include "help.h"
+#include <dead-kittens.h>
 
+#include <gnumeric-gconf.h>
 #include <gui-util.h>
 #include <search.h>
 #include <widgets/gnumeric-expr-entry.h>
 #include <wbc-gtk.h>
 #include <selection.h>
 
-#include <glade/glade.h>
 #include <goffice/goffice.h>
 #include <gtk/gtk.h>
 #include <string.h>
@@ -41,7 +44,7 @@
 
 typedef struct {
 	WBCGtk *wbcg;
-	GladeXML *gui;
+	GtkBuilder *gui;
 	GtkDialog *dialog;
 	GtkEntry *search_text;
 	GtkEntry *replace_text;
@@ -78,23 +81,49 @@ static const char * const direction_group[] = {
 };
 
 static gboolean
-is_checked (GladeXML *gui, const char *name)
+is_checked (GtkBuilder *gui, const char *name)
 {
-	GtkWidget *w = glade_xml_get_widget (gui, name);
+	GtkWidget *w = go_gtk_builder_get_widget (gui, name);
 	return gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (w));
 }
 
 static void
-set_checked (GladeXML *gui, const char *name, gboolean checked)
+set_checked (GtkBuilder *gui, const char *name, gboolean checked)
 {
-	GtkWidget *w = glade_xml_get_widget (gui, name);
+	GtkWidget *w = go_gtk_builder_get_widget (gui, name);
 	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (w), checked);
 }
 
+static void
+dialog_search_replace_save_in_prefs (DialogState *dd)
+{
+	GtkBuilder *gui = dd->gui;
+
+#define SETW(w,f) f (is_checked (gui, w));
+	SETW("search_expr", gnm_conf_set_searchreplace_change_cell_expressions);
+	SETW("search_other", gnm_conf_set_searchreplace_change_cell_other);
+	SETW("search_string", gnm_conf_set_searchreplace_change_cell_strings);
+	SETW("search_comments", gnm_conf_set_searchreplace_change_comments);
+	SETW("ignore_case", gnm_conf_set_searchreplace_ignore_case);
+	SETW("keep_strings", gnm_conf_set_searchreplace_keep_strings);
+	SETW("preserve_case", gnm_conf_set_searchreplace_preserve_case);
+	SETW("query", gnm_conf_set_searchreplace_query);
+	SETW("match_words", gnm_conf_set_searchreplace_whole_words_only);
+	SETW("column_major", gnm_conf_set_searchreplace_columnmajor);
+#undef SETW
+
+	gnm_conf_set_searchreplace_regex
+		(gnm_gui_group_value (gui, search_type_group));
+	gnm_conf_set_searchreplace_error_behaviour
+		(gnm_gui_group_value (gui, error_group));
+	gnm_conf_set_searchreplace_scope
+		(gnm_gui_group_value (gui, scope_group));
+}
+
 static void
 apply_clicked (G_GNUC_UNUSED GtkWidget *widget, DialogState *dd)
 {
-	GladeXML *gui = dd->gui;
+	GtkBuilder *gui = dd->gui;
 	GtkDialog *dialog = dd->dialog;
 	WBCGtk *wbcg = dd->wbcg;
 	SearchDialogCallback cb = dd->cb;
@@ -104,7 +133,7 @@ apply_clicked (G_GNUC_UNUSED GtkWidget *widget, DialogState *dd)
 	GnmSearchReplaceScope scope;
 	char *search_text, *replace_text;
 
-	i = gnumeric_glade_group_value (gui, scope_group);
+	i = gnm_gui_group_value (gui, scope_group);
 	scope = (i == -1) ? GNM_SRS_SHEET : (GnmSearchReplaceScope)i;
 
 	search_text = g_utf8_normalize (gtk_entry_get_text (dd->search_text), -1, G_NORMALIZE_DEFAULT);
@@ -116,7 +145,7 @@ apply_clicked (G_GNUC_UNUSED GtkWidget *widget, DialogState *dd)
 			   "range-text", gnm_expr_entry_get_text (dd->rangetext),
 			   "search-text", search_text,
 			   "replace-text", replace_text,
-			   "is-regexp", gnumeric_glade_group_value (gui, search_type_group) == 1,
+			   "is-regexp", gnm_gui_group_value (gui, search_type_group) == 1,
 			   "ignore-case", is_checked (gui, "ignore_case"),
 			   "match-words", is_checked (gui, "match_words"),
 			   "preserve-case", is_checked (gui, "preserve_case"),
@@ -127,15 +156,19 @@ apply_clicked (G_GNUC_UNUSED GtkWidget *widget, DialogState *dd)
 			   "search-expressions", is_checked (gui, "search_expr"),
 			   "search-expression-results", FALSE,
 			   "search-comments", is_checked (gui, "search_comments"),
-			   "by-row", gnumeric_glade_group_value (gui, direction_group) == 0,
+			   "by-row", gnm_gui_group_value (gui, direction_group) == 0,
 			   NULL);
 
 	g_free (search_text);
 	g_free (replace_text);
 
-	i = gnumeric_glade_group_value (gui, error_group);
+	i = gnm_gui_group_value (gui, error_group);
 	sr->error_behaviour = (i == -1) ? GNM_SRE_FAIL : (GnmSearchReplaceError)i;
 
+	if  (is_checked (gui, "save-in-prefs"))
+		dialog_search_replace_save_in_prefs (dd);
+
+
 	err = gnm_search_replace_verify (sr, TRUE);
 	if (err) {
 		go_gtk_notice_dialog (GTK_WINDOW (dialog), GTK_MESSAGE_ERROR,
@@ -162,7 +195,7 @@ static void
 ok_clicked (GtkWidget *widget, DialogState *dd)
 {
         apply_clicked (widget, dd);
-	
+
 	gtk_widget_destroy (GTK_WIDGET (dd->dialog));
 	dd = NULL;  /* Destroyed */
 }
@@ -189,7 +222,7 @@ range_focused (G_GNUC_UNUSED GtkWidget *widget,
 	       G_GNUC_UNUSED GdkEventFocus *event,
 	       DialogState *dd)
 {
-	GtkWidget *scope_range = glade_xml_get_widget (dd->gui, "scope_range");
+	GtkWidget *scope_range = go_gtk_builder_get_widget (dd->gui, "scope_range");
 	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (scope_range), TRUE);
 	return FALSE;
 }
@@ -209,7 +242,7 @@ void
 dialog_search_replace (WBCGtk *wbcg,
 		       SearchDialogCallback cb)
 {
-	GladeXML *gui;
+	GtkBuilder *gui;
 	GtkDialog *dialog;
 	DialogState *dd;
 	GtkTable *table;
@@ -224,12 +257,11 @@ dialog_search_replace (WBCGtk *wbcg,
 	if (gnumeric_dialog_raise_if_exists (wbcg, SEARCH_REPLACE_KEY))
 		return;
 
-	gui = gnm_glade_xml_new (GO_CMD_CONTEXT (wbcg),
-		"search-replace.glade", NULL, NULL);
+	gui = gnm_gtk_builder_new ("search-replace.ui", NULL, GO_CMD_CONTEXT (wbcg));
         if (gui == NULL)
                 return;
 
-	dialog = GTK_DIALOG (glade_xml_get_widget (gui, "search_replace_dialog"));
+	dialog = GTK_DIALOG (go_gtk_builder_get_widget (gui, "search_replace_dialog"));
 
 	dd = g_new (DialogState, 1);
 	dd->wbcg = wbcg;
@@ -237,7 +269,7 @@ dialog_search_replace (WBCGtk *wbcg,
 	dd->cb = cb;
 	dd->dialog = dialog;
 
-	table = GTK_TABLE (glade_xml_get_widget (gui, "search_table"));
+	table = GTK_TABLE (go_gtk_builder_get_widget (gui, "search_table"));
 	dd->search_text = GTK_ENTRY (gtk_entry_new ());
 	gtk_table_attach (table, GTK_WIDGET (dd->search_text),
 			  1, 4, 0, 1,
@@ -254,7 +286,7 @@ dialog_search_replace (WBCGtk *wbcg,
 	gnumeric_editable_enters (GTK_WINDOW (dialog),
 				  GTK_WIDGET (dd->replace_text));
 
-	table = GTK_TABLE (glade_xml_get_widget (gui, "scope_table"));
+	table = GTK_TABLE (go_gtk_builder_get_widget (gui, "scope_table"));
 	dd->rangetext = gnm_expr_entry_new (wbcg, TRUE);
 	gnm_expr_entry_set_flags (dd->rangetext, 0, GNM_EE_MASK);
 	gtk_table_attach (table, GTK_WIDGET (dd->rangetext),
@@ -268,13 +300,47 @@ dialog_search_replace (WBCGtk *wbcg,
 	g_free (selection_text);
 	gtk_widget_show (GTK_WIDGET (dd->rangetext));
 
-	g_signal_connect (G_OBJECT (glade_xml_get_widget (gui, "ok_button")),
+#define SETW(w,f) gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (go_gtk_builder_get_widget (gui, w)),  f())
+	SETW("search_expr", gnm_conf_get_searchreplace_change_cell_expressions);
+	SETW("search_other", gnm_conf_get_searchreplace_change_cell_other);
+	SETW("search_string", gnm_conf_get_searchreplace_change_cell_strings);
+	SETW("search_comments", gnm_conf_get_searchreplace_change_comments);
+	SETW("ignore_case", gnm_conf_get_searchreplace_ignore_case);
+	SETW("keep_strings", gnm_conf_get_searchreplace_keep_strings);
+	SETW("preserve_case", gnm_conf_get_searchreplace_preserve_case);
+	SETW("query", gnm_conf_get_searchreplace_query);
+	SETW("match_words", gnm_conf_get_searchreplace_whole_words_only);
+#undef SETW
+
+	gtk_toggle_button_set_active
+	  (GTK_TOGGLE_BUTTON
+	   (go_gtk_builder_get_widget
+	    (gui,
+	     search_type_group[gnm_conf_get_searchreplace_regex () ? 1 : 0])), TRUE);
+	gtk_toggle_button_set_active
+	  (GTK_TOGGLE_BUTTON
+	   (go_gtk_builder_get_widget
+	    (gui,
+	     direction_group[gnm_conf_get_searchreplace_columnmajor () ? 1 : 0])), TRUE);
+	gtk_toggle_button_set_active
+	  (GTK_TOGGLE_BUTTON
+	   (go_gtk_builder_get_widget
+	    (gui,
+	     error_group[gnm_conf_get_searchreplace_error_behaviour ()])), TRUE);
+	gtk_toggle_button_set_active
+	  (GTK_TOGGLE_BUTTON
+	   (go_gtk_builder_get_widget
+	    (gui,
+	     scope_group[gnm_conf_get_searchreplace_scope ()])), TRUE);
+
+
+	g_signal_connect (G_OBJECT (go_gtk_builder_get_widget (gui, "ok_button")),
 		"clicked",
 		G_CALLBACK (ok_clicked), dd);
-	g_signal_connect (G_OBJECT (glade_xml_get_widget (gui, "apply_button")),
+	g_signal_connect (G_OBJECT (go_gtk_builder_get_widget (gui, "apply_button")),
 		"clicked",
 		G_CALLBACK (apply_clicked), dd);
-	g_signal_connect (G_OBJECT (glade_xml_get_widget (gui, "cancel_button")),
+	g_signal_connect (G_OBJECT (go_gtk_builder_get_widget (gui, "cancel_button")),
 		"clicked",
 		G_CALLBACK (cancel_clicked), dd);
 	g_signal_connect (GTK_OBJECT (gnm_expr_entry_get_entry (dd->rangetext)),
@@ -282,12 +348,12 @@ dialog_search_replace (WBCGtk *wbcg,
 		G_CALLBACK (range_focused), dd);
 
 	gnumeric_init_help_button (
-		glade_xml_get_widget (gui, "help_button"),
+		go_gtk_builder_get_widget (gui, "help_button"),
 		GNUMERIC_HELP_LINK_SEARCH_REPLACE);
 	g_object_set_data_full (G_OBJECT (dialog),
 		"state", dd, (GDestroyNotify) cb_dialog_destroy);
 
-	gtk_widget_show_all (dialog->vbox);
+	gtk_widget_show_all (gtk_dialog_get_content_area (dialog));
 	gtk_widget_grab_focus (GTK_WIDGET (dd->search_text));
 
 	gnm_dialog_setup_destroy_handlers (dialog, wbcg,
@@ -304,25 +370,25 @@ dialog_search_replace_query (WBCGtk *wbcg,
 			     const char *old_text,
 			     const char *new_text)
 {
-	GladeXML *gui;
+	GtkBuilder *gui;
 	GtkDialog *dialog;
 	int res;
 
 	g_return_val_if_fail (wbcg != NULL, 0);
 
-	gui = gnm_glade_xml_new (GO_CMD_CONTEXT (wbcg),
-		"search-replace.glade", NULL, NULL);
+	gui = gnm_gtk_builder_new ("search-replace.ui", NULL, GO_CMD_CONTEXT (wbcg));
         if (gui == NULL)
                 return 0;
 
-	dialog = GTK_DIALOG (glade_xml_get_widget (gui, "query_dialog"));
+	dialog = GTK_DIALOG (go_gtk_builder_get_widget (gui, "query_dialog"));
 
-	gtk_entry_set_text (GTK_ENTRY (glade_xml_get_widget (gui, "qd_location")),
+	gtk_entry_set_text (GTK_ENTRY (go_gtk_builder_get_widget (gui, "qd_location")),
 			    location);
-	gtk_entry_set_text (GTK_ENTRY (glade_xml_get_widget (gui, "qd_old_text")),
+	gtk_entry_set_text (GTK_ENTRY (go_gtk_builder_get_widget (gui, "qd_old_text")),
 			    old_text);
-	gtk_entry_set_text (GTK_ENTRY (glade_xml_get_widget (gui, "qd_new_text")),
+	gtk_entry_set_text (GTK_ENTRY (go_gtk_builder_get_widget (gui, "qd_new_text")),
 			    new_text);
+
 	set_checked (gui, "qd_query", sr->query);
 
 	wbcg_set_transient (wbcg, GTK_WINDOW (dialog));
