@@ -1494,8 +1494,11 @@ gnm_expr_eval (GnmExpr const *expr, GnmEvalPos const *pos,
 		/* The upper left corner manages the recalc of the expr */
 		GnmCell *corner = array_elem_get_corner (&expr->array_elem,
 			pos->sheet, &pos->eval);
-		if (corner == NULL)
+		if (!corner ||
+		    !gnm_expr_top_is_array_corner (corner->base.texpr)) {
+			g_warning ("Funky array setup.");
 			return handle_empty (NULL, flags);
+		}
 
 		gnm_cell_eval (corner);
 		a = corner->base.texpr->expr->array_corner.value;
@@ -2506,6 +2509,24 @@ gnm_expr_get_range (GnmExpr const *expr)
 	}
 }
 
+static gint
+gnm_insert_unique_value_cmp (gconstpointer a, gconstpointer b)
+{
+	return (value_equal (a,b) ? 0 : 1);
+}
+
+
+
+static GSList *
+gnm_insert_unique_value (GSList *list, GnmValue *data)
+{
+	if (g_slist_find_custom (list, data,
+				 gnm_insert_unique_value_cmp)
+	    == NULL)
+		return g_slist_prepend (list, data);
+	value_release (data);
+	return list;
+}
 
 static GSList *
 do_gnm_expr_get_ranges (GnmExpr const *expr, GSList *ranges)
@@ -2542,7 +2563,7 @@ do_gnm_expr_get_ranges (GnmExpr const *expr, GSList *ranges)
 	default: {
 		GnmValue *v = gnm_expr_get_range (expr);
 		if (v)
-			return gnm_insert_unique (ranges, v);
+			return gnm_insert_unique_value (ranges, v);
 		return ranges;
 	}
 	}
