@@ -1236,6 +1236,32 @@ gnm_conf_get_core_gui_editing_portraitmode_node (void)
 {
 	return get_node (watch_core_gui_editing_portraitmode.key);
 }
+
+static struct cb_watch_bool watch_core_gui_editing_launchpage = {
+	0, "core/gui/editing/launchpage", FALSE,
+};
+
+gboolean
+gnm_conf_get_core_gui_editing_launchpage (void)
+{
+	if (!watch_core_gui_editing_launchpage.handler)
+		watch_bool (&watch_core_gui_editing_launchpage);
+	return watch_core_gui_editing_launchpage.var;
+}
+
+void
+gnm_conf_set_core_gui_editing_launchpage (gboolean x)
+{
+	if (!watch_core_gui_editing_launchpage.handler)
+		watch_bool (&watch_core_gui_editing_launchpage);
+	set_bool (&watch_core_gui_editing_launchpage, x);
+}
+
+GOConfNode *
+gnm_conf_get_core_gui_editing_launchpage_node (void)
+{
+	return get_node (watch_core_gui_editing_launchpage.key);
+}
 #endif
 
 gboolean
